#' @importFrom Rcpp loadModule cpp_object_initializer
Rcpp::loadModule("gillespie", TRUE)
